@@ -38,7 +38,6 @@
   #undef GCR_API_SUBJECT_TO_CHANGE
 #endif
 
-#include <pan/general/null.h>
 
 using namespace pan;
 
@@ -51,7 +50,7 @@ namespace
 
   std::string get_cache_path ()
   {
-    char * pch (g_build_filename (file::get_pan_home().c_str(), "article-cache", NULL));
+    char * pch (g_build_filename (file::get_pan_home().c_str(), "article-cache", nullptr));
     file :: ensure_dir_exists (pch);
     std::string path (pch);
     g_free (pch);
@@ -60,7 +59,7 @@ namespace
 
   std::string get_encode_cache_path ()
   {
-    char * pch (g_build_filename (file::get_pan_home().c_str(), "encode-cache", NULL));
+    char * pch (g_build_filename (file::get_pan_home().c_str(), "encode-cache", nullptr));
     file :: ensure_dir_exists (pch);
     std::string path (pch);
     g_free (pch);
@@ -69,22 +68,26 @@ namespace
 
 }
 
-DataImpl :: DataImpl (const StringView& cache_ext, Prefs& prefs, bool unit_test, int cache_megs, DataIO * io):
-  ProfilesImpl (*io),
-  _cache (get_cache_path(), cache_ext, cache_megs),
-  _encode_cache (get_encode_cache_path(), cache_megs),
+DataImpl ::DataImpl(StringView const &cache_ext,
+                    Prefs &prefs,
+                    bool unit_test,
+                    int cache_megs,
+                    DataIO *io) :
+  ProfilesImpl(*io),
+  _cache(get_cache_path(), cache_ext, cache_megs),
+  _encode_cache(get_encode_cache_path(), cache_megs),
   _certstore(*this),
   _queue(nullptr),
-  _unit_test (unit_test),
-  _data_io (io),
+  _unit_test(unit_test),
+  _data_io(io),
   _prefs(prefs),
-  _descriptions_loaded (false),
+  _descriptions_loaded(false),
   _cached_xover_entry(nullptr),
-  _rules_filter (prefs.get_flag("rules-autocache-mark-read", false),
-                 prefs.get_flag("rules-auto-dl-mark-read", false),
-                 prefs.get_flag("rules-autocache-mark-read", false)),
-  newsrc_autosave_id (0),
-  newsrc_autosave_timeout (0)
+  _rules_filter(prefs.get_flag("rules-autocache-mark-read", false),
+                prefs.get_flag("rules-auto-dl-mark-read", false),
+                prefs.get_flag("rules-autocache-mark-read", false)),
+  newsrc_autosave_id(0),
+  newsrc_autosave_timeout(0)
 {
   rebuild_backend ();
 }
@@ -143,7 +146,7 @@ DataImpl :: get_scorefile_name() const
 gboolean
 DataImpl :: password_encrypt (const PasswordData& pw)
 {
-GError *error_c = NULL;
+GError *error_c = nullptr;
 
   return (
     secret_password_store_sync (
@@ -151,10 +154,10 @@ GError *error_c = NULL;
       SECRET_COLLECTION_DEFAULT,
       _("Pan Newsreader's server passwords"),
       pw.pw,
-      NULL, &error_c,
+      nullptr, &error_c,
       "user", pw.user.str,
       "server", pw.server.c_str(),
-      NULL)
+      nullptr)
     );
 
 }
@@ -162,17 +165,17 @@ GError *error_c = NULL;
 gchar*
 DataImpl :: password_decrypt (PasswordData& pw) const
 {
-  GError *error_c = NULL;
-  gchar* pwd = NULL;
+  GError *error_c = nullptr;
+  gchar* pwd = nullptr;
 
   pwd =
     secret_password_lookup_sync (
     SECRET_SCHEMA_COMPAT_NETWORK,
-    NULL,
+    nullptr,
     &error_c,
     "user", pw.user.str,
     "server", pw.server.c_str(),
-    NULL);
+    nullptr);
 
   if (pwd)
   {
