@@ -20,7 +20,8 @@
 #ifndef __PanFileEntry_h__
 #define __PanFileEntry_h__
 
-#include "gtk-compat.h"
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 
 namespace pan
 {
