@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <config.h>
@@ -24,7 +24,7 @@
 #include <set>
 #include <gobject/gvaluecollector.h>
 #include <pan/general/debug.h>
-#include <pan/general/foreach.h>
+#include <pan/general/macros.h>
 #include "pan-tree.h"
 
 #define IS_SORTED(tree) \
@@ -118,8 +118,8 @@ PanTreeStore :: set_iter (GtkTreeIter * iter,
 {
   iter->stamp = stamp;
   iter->user_data = (gpointer)row;
-  iter->user_data2 = 0;
-  iter->user_data3 = 0;
+  iter->user_data2 = nullptr;
+  iter->user_data3 = nullptr;
 }
 
 void
@@ -131,6 +131,17 @@ PanTreeStore :: invalidate_iter (GtkTreeIter * iter)
   iter->user_data2 = (void*) 0xDEADBEEF;
 }
 
+bool
+PanTreeStore :: set_or_invalidate (GtkTreeIter * iter, const Row * row)
+{
+  if (row)
+    set_iter (iter, row);
+  else
+    invalidate_iter (iter);
+  return row != nullptr;
+}
+
+
 /*****
 ******
 ******  implementing GtkTreeModel's interface
@@ -138,7 +149,7 @@ PanTreeStore :: invalidate_iter (GtkTreeIter * iter)
 *****/
 
 GtkTreeModelFlags
-PanTreeStore :: model_get_flags (GtkTreeModel *tree_model)
+PanTreeStore :: model_get_flags (GtkTreeModel *)
 {
   return GTK_TREE_MODEL_ITERS_PERSIST;
 }
@@ -191,7 +202,7 @@ PanTreeStore :: model_get_path (GtkTreeModel * model,
                                 GtkTreeIter  * iter)
 {
   PanTreeStore * store (PAN_TREE_STORE(model));
-  g_return_val_if_fail (store, 0);
+  g_return_val_if_fail (store, nullptr);
   return store->get_path (iter);
 }
 
@@ -223,12 +234,7 @@ PanTreeStore :: model_iter_next (GtkTreeModel * model,
   Row * row (tree->get_row (iter));
   row = row->parent->nth_child (row->child_index + 1);
 
-  if (row)
-    tree->set_iter (iter, row);
-  else
-    invalidate_iter (iter);
-
-  return row != 0;
+  return tree->set_or_invalidate (iter, row);
 }
 
 gboolean
@@ -272,12 +278,7 @@ PanTreeStore :: model_iter_nth_child (GtkTreeModel * model,
   Row * row (parent ? tree->get_row(parent) : tree->root);
   row = row->nth_child (n);
 
-  if (row)
-    tree->set_iter (iter, row);
-  else
-    invalidate_iter (iter);
-
-  return row != 0;
+  return tree->set_or_invalidate (iter, row);
 }
 
 gboolean
@@ -295,7 +296,7 @@ PanTreeStore :: model_iter_parent (GtkTreeModel * model,
 GtkTreePath*
 PanTreeStore :: get_path (const Row * row) const
 {
-  g_return_val_if_fail (row, false);
+  g_return_val_if_fail (row, NULL);
 
   std::vector<int> indices;
   while (row && row!=root) {
@@ -313,8 +314,8 @@ PanTreeStore :: get_path (const Row * row) const
 GtkTreePath*
 PanTreeStore :: get_path (GtkTreeIter  * iter)
 {
-  g_return_val_if_fail (iter, false);
-  g_return_val_if_fail (iter->stamp == stamp, false);
+  g_return_val_if_fail (iter, NULL);
+  g_return_val_if_fail (iter->stamp == stamp, NULL);
 
   return get_path (get_row (iter));
 }
@@ -328,12 +329,7 @@ PanTreeStore :: get_parent (GtkTreeIter * iter,
   g_return_val_if_fail (child->stamp == stamp, false);
 
   const Row * row (get_row (child));
-  const bool has_public_parent (row->parent != root);
-  if (has_public_parent)
-    set_iter (iter, row->parent);
-  else
-    invalidate_iter (iter);
-  return has_public_parent;
+  return set_or_invalidate (iter, row->parent!=root ? row->parent : nullptr);
 }
 
 bool
@@ -365,7 +361,7 @@ PanTreeStore :: is_in_tree (Row * row) const
     row = row->parent;
   return row == root;
 }
-  
+
 /*****
 ******
 ******  implementing GtkTreeSortable
@@ -395,7 +391,7 @@ PanTreeStore :: sortable_has_sort_func (GtkTreeSortable *sortable, gint col)
   PanTreeStore * store (PAN_TREE_STORE (sortable));
   g_return_val_if_fail (store, false);
   column_sort_info_t::const_iterator it (store->sort_info->find (col));
-  return (it!=store->sort_info->end()) && (it->second.sort_func!=0);
+  return (it!=store->sort_info->end()) && (it->second.sort_func!=nullptr);
 }
 
 // SORTING
@@ -491,7 +487,7 @@ PanTreeStore :: sort_children (SortInfo  & sort_info,
     if (parent == root)
     {
       GtkTreePath * path (gtk_tree_path_new ());
-      gtk_tree_model_rows_reordered (model, path, 0, new_order);
+      gtk_tree_model_rows_reordered (model, path, nullptr, new_order);
       gtk_tree_path_free (path);
     }
     else
@@ -536,7 +532,7 @@ PanTreeStore :: sortable_set_sort_column_id (GtkTreeSortable * sortable,
   // sanity checks...
   if (sort_column_id != GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID) {
     g_return_if_fail (tree->sort_info->count(sort_column_id) != 0);
-    g_return_if_fail (tree->sort_info->find(sort_column_id)->second.sort_func != 0);
+    g_return_if_fail (tree->sort_info->find(sort_column_id)->second.sort_func != nullptr);
   }
 
   const bool flip (sort_column_id == tree->sort_column_id);
@@ -558,7 +554,7 @@ PanTreeStore :: sortable_set_sort_func (GtkTreeSortable        *sortable,
                                         gint                    col,
                                         GtkTreeIterCompareFunc  func,
                                         gpointer                data,
-                                        GtkDestroyNotify        destroy)
+                                        GDestroyNotify          destroy)
 {
   PanTreeStore * tree (PAN_TREE_STORE (sortable));
   g_return_if_fail (tree);
@@ -573,14 +569,14 @@ void
 PanTreeStore :: sortable_set_default_sort_func (GtkTreeSortable        * s,
                                                 GtkTreeIterCompareFunc   f,
                                                 gpointer                 p,
-                                                GtkDestroyNotify         d)
+                                                GDestroyNotify           d)
 {
   sortable_set_sort_func (s, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, f, p, d);
 }
 
 namespace
 {
-  GObjectClass *parent_class (0);
+  GObjectClass *parent_class (nullptr);
 
   typedef std::vector<GValue> values_t;
 }
@@ -591,7 +587,8 @@ PanTreeStore :: FreeRowWalker: public PanTreeStore::WalkFunctor
   PanTreeStore * store;
   FreeRowWalker (PanTreeStore *t): store(t) {}
   virtual ~FreeRowWalker () {}
-  virtual bool operator()(PanTreeStore *s, Row *r, GtkTreeIter*it, GtkTreePath *p) {
+  bool operator()(PanTreeStore *s, Row *r, GtkTreeIter*, GtkTreePath*) override
+  {
     if (store->row_dispose)
         store->row_dispose->row_dispose (s, r);
     else
@@ -621,9 +618,9 @@ PanTreeStore :: pan_tree_finalize (GObject *object)
   delete store->root;
   delete store->column_types;
   delete store->sort_info;
-  store->root = 0;
-  store->column_types = 0;
-  store->sort_info = 0;
+  store->root = nullptr;
+  store->column_types = nullptr;
+  store->sort_info = nullptr;
 
   (*parent_class->finalize) (object);
 }
@@ -670,7 +667,7 @@ PanTreeStore :: pan_tree_sortable_init (GtkTreeSortableIface *iface)
 namespace
 {
   class RootRow: public PanTreeStore::Row {
-    virtual void get_value (int column, GValue * setme) { /* unused */ }
+    void get_value (int, GValue *) override { /* unused */ }
   };
 }
 
@@ -680,7 +677,7 @@ PanTreeStore :: pan_tree_init (PanTreeStore * tree)
   tree->stamp = g_random_int();
   tree->n_columns = 0;
   tree->root = new RootRow ();
-  tree->row_dispose = 0;
+  tree->row_dispose = nullptr;
   tree->column_types = new std::vector<GType>();
   tree->sort_paused = 0;
   tree->sort_info = new column_sort_info_t;
@@ -708,17 +705,18 @@ PanTreeStore :: get_type ()
     NULL, // class_data
     sizeof (PanTreeStore),
     0, // n_preallocs
-    (GInstanceInitFunc) pan_tree_init
+    (GInstanceInitFunc) pan_tree_init,
+    nullptr // value_table
   };
 
   pan_tree_type = g_type_register_static (
     G_TYPE_OBJECT, "PanTreeStore", &pan_tree_info, (GTypeFlags)0);
   static const GInterfaceInfo tree_model_info =
-    { (GInterfaceInitFunc)pan_tree_model_init, 0, 0 };
+    { (GInterfaceInitFunc)pan_tree_model_init, nullptr, nullptr };
   g_type_add_interface_static (
     pan_tree_type, GTK_TYPE_TREE_MODEL, &tree_model_info);
   static const GInterfaceInfo sortable_info =
-    { (GInterfaceInitFunc)pan_tree_sortable_init, 0, 0 };
+    { (GInterfaceInitFunc)pan_tree_sortable_init, nullptr, nullptr };
   g_type_add_interface_static (
     pan_tree_type, GTK_TYPE_TREE_SORTABLE, &sortable_info);
   return pan_tree_type;
@@ -727,7 +725,7 @@ PanTreeStore :: get_type ()
 PanTreeStore*
 PanTreeStore :: new_tree (int n_columns, ...)
 {
-  g_return_val_if_fail (n_columns>0, 0);
+  g_return_val_if_fail (n_columns>0, nullptr);
   PanTreeStore* tree = (PanTreeStore*) g_object_new (PAN_TREE_STORE_TYPE, NULL);
 
   va_list args;
@@ -819,14 +817,14 @@ PanTreeStore :: insert_sorted (const parent_to_children_t& new_parents)
 
     // sort these from shallowest to deepest
     std::sort (keys.begin(), keys.end(), depth_compare);
- 
+
     // process each of them
     foreach_const (rows_t, keys, it)
     {
       // add the children to this parent...
       // caller passes in NULL for the parent of top-level articles...
       Row * parent (*it);
-      Row * key (parent==root ? 0 : parent);
+      Row * key (parent==root ? nullptr : parent);
       const rows_t& children (new_parents.find(key)->second);
       insert_sorted (parent, children);
       pool.erase (parent);
@@ -856,7 +854,7 @@ struct PanTreeStore :: RowCompareByColumn
   {
     GtkTreeIter a_it (store->get_iter (a));
     GtkTreeIter b_it (store->get_iter (b));
-    int val = (sort_func)(model, &a_it, &b_it, user_data);
+    int val = sort_func ? (sort_func)(model, &a_it, &b_it, user_data) : (a<b);
     if (reverse) val = -val;
     return val < 0;
   }
@@ -874,8 +872,8 @@ struct PanTreeStore::ReparentWalker: public PanTreeStore::WalkFunctor
 
   virtual ~ReparentWalker () {}
 
-  virtual bool operator()(PanTreeStore *store, Row* row,
-                          GtkTreeIter *iter, GtkTreePath *path)
+  bool operator()(PanTreeStore *store, Row* row,
+                          GtkTreeIter *iter, GtkTreePath *path) override
   {
     const int n_children (row->n_children());
 
@@ -937,7 +935,7 @@ PanTreeStore :: insert_sorted (Row           * parent,
                          n_it  (children.begin()),
                          n_end (children.end());
   for (size_t i=0; o_it!=o_end || n_it!=n_end; ++i) {
-    Row * addme (0);
+    Row * addme (nullptr);
     if ((n_it==n_end)) {
       //std::cerr << LINE_ID << " n is empty ... adding another o at " << tmp.size() << std::endl;
       addme = *o_it++;
@@ -1064,7 +1062,7 @@ PanTreeStore :: reparent (Row  * new_parent,
                           Row  * row,
                           int    position)
 {
-  g_return_if_fail (row != 0);
+  g_return_if_fail (row != nullptr);
 
   GtkTreeModel * model (GTK_TREE_MODEL(this));
 
@@ -1120,7 +1118,7 @@ PanTreeStore :: reparent (const parent_to_children_t& new_parents)
 
   insert_sorted (new_parents);
 }
-  
+
 /***
 ****
 ***/
@@ -1156,8 +1154,8 @@ struct PanTreeStore::ClearWalker: public PanTreeStore::WalkFunctor
   }
 
   virtual bool operator()(PanTreeStore* store,
-                          PanTreeStore::Row* row,
-                          GtkTreeIter* iter, GtkTreePath* path)
+                          PanTreeStore::Row*,
+                          GtkTreeIter* iter, GtkTreePath*)
   {
     clear_children (store, store->get_row(iter));
     return true;
@@ -1197,23 +1195,21 @@ PanTreeStore :: remove_siblings (const rows_t& siblings,
   foreach_const (rows_t, siblings, nit) {
     Row * row (*nit);
     removed_indices.insert (row->child_index);
-    row->parent = 0;
+    row->parent = nullptr;
     row->child_index = -1;
   }
 
   // remove the dead rows; re-index the live ones
   int pos (0);
-  rows_t keepers;
+  rows_t keepers, purged;
   keepers.reserve (parent->n_children());
   foreach_const (rows_t, parent->children, it) {
     Row * row (*it);
-    if (row->parent) {
+    if (!row->parent)
+      purged.push_back (row);
+    else {
       row->child_index = pos++;
       keepers.push_back (row);
-    } else if (delete_rows) {
-      FreeRowWalker walk (this);
-      GtkTreeIter iter (get_iter (row));
-      postfix_walk (walk, &iter);
     }
   }
   parent->children.swap (keepers);
@@ -1232,6 +1228,17 @@ PanTreeStore :: remove_siblings (const rows_t& siblings,
     gtk_tree_model_row_has_child_toggled (model, path, &pit);
   }
 
+  // clean up purged rows
+  if (delete_rows) {
+    foreach (rows_t, purged, it) {
+      Row * row (*it);
+      g_assert (row->child_index == -1);
+      FreeRowWalker walk (this);
+      GtkTreeIter iter (get_iter (row));
+      postfix_walk (walk, &iter);
+    }
+  }
+
   gtk_tree_path_free (path);
 }
 
@@ -1282,7 +1289,7 @@ PanTreeStore :: walk (int             walk_mode,
                       GtkTreeIter   * top,
                       bool            need_path)
 {
-  GtkTreePath * path (0);
+  GtkTreePath * path (nullptr);
   if (need_path)
     path = top ? get_path(top) : gtk_tree_path_new();
 
@@ -1306,3 +1313,61 @@ PanTreeStore :: postfix_walk (WalkFunctor   & walker,
 {
   walk (WALK_POSTFIX, walker, top, need_path);
 }
+
+/***
+****
+***/
+
+PanTreeStore :: Row*
+PanTreeStore :: get_prev (Row * row)
+{
+  if (!row || row==root)
+    return nullptr;
+  if (row->child_index==0)
+    return row->parent==root ? nullptr : row->parent;
+  Row * sibling = row->parent->nth_child (row->child_index-1);
+  return sibling->get_last_descendant ();
+}
+
+PanTreeStore :: Row*
+PanTreeStore :: get_next (Row * row)
+{
+  // child
+  if (!row->children.empty())
+    return row->nth_child (0);
+
+  // sibling
+  while (row && row!=root) {
+    Row * sibling = row->parent->nth_child (row->child_index + 1);
+    if (sibling)
+      return sibling;
+    row = row->parent;
+  }
+
+  // if all else fails, just return the first node
+  return root->nth_child(0);
+}
+
+bool
+PanTreeStore :: get_prev (GtkTreeIter * iter)
+{
+  return set_or_invalidate (iter, get_prev(get_row(iter)));
+}
+
+bool
+PanTreeStore :: get_next (GtkTreeIter * iter)
+{
+  return set_or_invalidate (iter, get_next(get_row(iter)));
+}
+
+bool
+PanTreeStore :: back (GtkTreeIter * iter)
+{
+  return set_or_invalidate (iter, root->get_last_descendant());
+}
+
+bool
+PanTreeStore :: front (GtkTreeIter * iter)
+{
+  return set_or_invalidate (iter, get_next(root));
+}
