@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <config.h>
@@ -29,23 +29,45 @@
 ****
 ***/
 
+// TODO Mulithreading downloads!
+
 using namespace pan;
 
+Queue :: task_states_t :: task_states_t ()
+  : _decoding (NULL)
+  , _encoding (NULL)
+{
+}
+
 Queue :: Queue (ServerInfo         & server_info,
                 TaskArchive        & archive,
-                Socket::Creator    * socket_creator,
+                Data               & data,
+                SocketCreator      * socket_creator,
+                CertStore          & certstore,
+                Prefs              & prefs,
                 WorkerPool         & pool,
-                bool                 online):
+                bool                 online,
+                int                  save_delay_secs):
   _server_info (server_info),
   _is_online (online),
   _socket_creator (socket_creator),
   _worker_pool (pool),
   _decoder (pool),
-  _decoder_task (0),
+  _encoder (pool),
+  _decoder_task (nullptr),
+  _encoder_task (nullptr),
+  _save_delay_secs (save_delay_secs),
   _needs_saving (false),
   _last_time_saved (0),
-  _archive (archive)
+  _archive (archive),
+  _uploads_total(0),
+  _downloads_total(0),
+  _certstore(certstore),
+  _prefs (prefs)
 {
+
+  data.set_queue(this);
+
   tasks_t tasks;
   _archive.load_tasks (tasks);
   add_tasks (tasks, BOTTOM);
@@ -61,6 +83,8 @@ Queue :: ~Queue ()
     delete it->second;
   _pools.clear ();
 
+  clean_n_save();
+
   foreach (TaskSet, _tasks, it)
     delete *it;
 }
@@ -69,7 +93,7 @@ void
 Queue :: on_pool_has_nntp_available (const Quark& server)
 {
   Task * task = find_first_task_needing_server (server);
-  if (task != 0)
+  if (task != nullptr)
     process_task (task);
 }
 
@@ -82,7 +106,7 @@ Queue :: on_pool_error (const Quark& server UNUSED, const StringView& message)
 NNTP_Pool&
 Queue :: get_pool (const Quark& servername)
 {
-  NNTP_Pool * pool (0);
+  NNTP_Pool * pool (nullptr);
 
   pools_t::iterator it (_pools.find (servername));
   if (it != _pools.end())
@@ -91,7 +115,7 @@ Queue :: get_pool (const Quark& servername)
   }
   else // have to build one
   {
-    pool = new NNTP_Pool (servername, _server_info, _socket_creator);
+    pool = new NNTP_Pool (servername, _server_info, _prefs, _socket_creator, _certstore);
     pool->add_listener (this);
     _pools[servername] = pool;
   }
@@ -102,19 +126,35 @@ Queue :: get_pool (const Quark& servername)
 /***
 ****
 ***/
+void
+Queue :: clean_n_save ()
+{
+
+  const tasks_t tmp (_tasks.begin(), _tasks.end());
+  // remove completed tasks.
+  foreach_const (tasks_t, tmp, it) {
+    Task * task  (*it);
+    const Task::State& state (task->get_state());
+    if (state._work==Task::COMPLETED || _removing.count(task))
+      remove_task (task);
+  }
+
+  // maybe save the task list.
+  // only do it once in awhile to prevent thrashing.
+  const time_t now (time(nullptr));
+  if (_needs_saving && _last_time_saved<(now-_save_delay_secs)) {
+    _archive.save_tasks (tmp);
+    _needs_saving = false;
+    _last_time_saved = time(nullptr);
+  }
+}
 
 void
 Queue :: upkeep ()
 {
-  // maybe save the task list.
-  // only do it once in awhile to prevent thrashing.
+  clean_n_save();
+
   const tasks_t tmp (_tasks.begin(), _tasks.end());
-  const time_t now (time(0));
-  if (_needs_saving && _last_time_saved<(now-10)) {
-    _archive.save_tasks (tmp);
-    _needs_saving = false;
-    _last_time_saved = now;
-  }
 
   // do upkeep on the first queued task.
   // the CPU goes crazy if we run upkeep on _all_ queued tasks,
@@ -123,20 +163,12 @@ Queue :: upkeep ()
   // ref #352170, #354779
   foreach_const (tasks_t, tmp, it) {
     Task * task (*it);
-    if (task->get_state()._work == Task::NEED_NNTP) {
+    if (task->get_state()._work == Task::NEED_NNTP ) {
       process_task (task);
       break;
     }
   }
 
-  // remove completed tasks.
-  foreach_const (tasks_t, tmp, it) {
-    Task * task  (*it);
-    const Task::State& state (task->get_state());
-    if (state._work==Task::COMPLETED || _removing.count(task))
-      remove_task (task);
-  }
-
   // upkeep on running tasks... this lets us pop open
   // extra connections if the task can handle >1 connection
   std::set<Task*> active;
@@ -189,6 +221,8 @@ Queue :: get_task_counts (int& active, int& total)
     active_tasks.insert (it->second);
   if (_decoder_task)
     active_tasks.insert (_decoder_task);
+  if (_encoder_task)
+    active_tasks.insert (_encoder_task);
   active = active_tasks.size ();
   total = _tasks.size ();
 }
@@ -203,6 +237,16 @@ Queue :: give_task_a_decoder (Task * task)
   task->give_decoder (this, &_decoder); // it's active now...
 }
 
+void
+Queue :: give_task_a_encoder (Task * task)
+{
+  const bool was_active (task_is_active (task));
+  _encoder_task = task;
+  if (!was_active)
+    fire_task_active_changed (task, true);
+  task->give_encoder (this, &_encoder); // it's active now...
+}
+
 void
 Queue :: give_task_a_connection (Task * task, NNTP * nntp)
 {
@@ -214,10 +258,36 @@ Queue :: give_task_a_connection (Task * task, NNTP * nntp)
   task->give_nntp (this, nntp);
 }
 
+void
+Queue :: give_task_an_upload_slot (TaskUpload* task)
+{
+  int max (_server_info.get_server_limits(task->_server));
+  if (_uploads.size() < max)
+  {
+    _uploads.insert(task);
+    task->wakeup();
+    fire_task_active_changed (task, true);
+    process_task(task);
+  }
+}
+
+void
+Queue :: give_task_a_download_slot (TaskArticle* task)
+{
+  int max (8);//DBG!!(_server_info.get_server_limits(task->_server));
+  if (_downloads.size() < max)
+  {
+    _downloads.insert(task);
+    task->wakeup();
+    fire_task_active_changed (task, true);
+    process_task(task);
+  }
+}
+
 void
 Queue :: process_task (Task * task)
 {
-  pan_return_if_fail (task!=0);
+  pan_return_if_fail (task != nullptr);
 
   debug ("in process_task with a task of type " << task->get_type());
 
@@ -238,35 +308,65 @@ Queue :: process_task (Task * task)
     debug ("stopped");
     task->stop();
   }
-  else if ((state._health == ERR_COMMAND) || (state._health == ERR_LOCAL))
+  else if (state._health == ERR_COMMAND || state._health == ERR_LOCAL)
   {
     debug ("fail");
     // do nothing
   }
+  else if (state._health==ERR_NOSPACE)
+  {
+    debug ("no space");
+    set_online(false);
+  }
   else if (state._work == Task::WORKING)
   {
     debug ("working");
-    // do nothing
+  }
+  else if (state._work == Task::INITIAL)
+  {
+    TaskUpload* t = dynamic_cast<TaskUpload*>(task);
+    if (t)
+      give_task_an_upload_slot(t);
+    // todo multihtreading for taskarticle
+//    TaskArticle* t2 = dynamic_cast<TaskArticle*>(task);
+//    if (t2)
+//      give_task_a_download_slot(t2);
   }
   else if (state._work == Task::NEED_DECODER)
   {
     if (!_decoder_task)
       give_task_a_decoder (task);
   }
+  else if (state._work == Task::NEED_ENCODER)
+  {
+    if (!_encoder_task)
+      give_task_a_encoder (task);
+  }
+
   else while (_is_online && (state._work == Task::NEED_NNTP))
   {
+    debug("online");
     // make the requests...
     const Task::State::unique_servers_t& servers (state._servers);
     foreach_const (Task::State::unique_servers_t, servers, it)
+    {
+      if (_certstore.in_blacklist(*it)) continue;
       get_pool(*it).request_nntp (_worker_pool);
+    }
 
     Quark server;
     if (!find_best_server (servers, server))
+    {
+      debug("break");
       break;
+    }
 
     NNTP * nntp (get_pool(server).check_out ());
     if (!nntp)
+    {
+      debug("break");
       break;
+    }
 
     give_task_a_connection (task, nntp);
   }
@@ -287,7 +387,21 @@ Queue :: find_first_task_needing_decoder ()
       return *it;
   }
 
-  return 0;
+  return nullptr;
+}
+
+Task*
+Queue :: find_first_task_needing_encoder ()
+{
+  foreach (TaskSet, _tasks, it) {
+    const Task::State& state ((*it)->get_state ());
+    if  ((state._work == Task::NEED_ENCODER)
+      && (!_stopped.count (*it))
+      && (!_removing.count (*it)))
+      return *it;
+  }
+
+  return nullptr;
 }
 
 Task*
@@ -295,7 +409,8 @@ Queue :: find_first_task_needing_server (const Quark& server)
 {
   foreach (TaskSet, _tasks, it) {
     const Task::State& state ((*it)->get_state ());
-    if  (((state._health != ERR_COMMAND) && (state._health != ERR_LOCAL))
+    if  (state._health != ERR_COMMAND && state._health != ERR_LOCAL
+      && state._health != ERR_NOSPACE
       && (state._work == Task::NEED_NNTP)
       && (state._servers.count(server))
       && (!_stopped.count (*it))
@@ -303,7 +418,7 @@ Queue :: find_first_task_needing_server (const Quark& server)
       return *it;
   }
 
-  return 0;
+  return nullptr;
 }
 
 bool
@@ -437,6 +552,12 @@ Queue :: stop_tasks (const tasks_t& tasks)
     if (_tasks.index_of (task) != -1) {
       _stopped.insert (task);
       process_task (task);
+
+      TaskArticle* ta = dynamic_cast<TaskArticle*>(*it);
+      if (ta)
+      {
+        ta->set_start_paused(true);
+      }
     }
   }
 }
@@ -449,6 +570,12 @@ Queue :: restart_tasks (const tasks_t& tasks)
     if (_tasks.index_of(task) != -1) {
       _stopped.erase (task);
       process_task (task);
+
+      TaskArticle* ta = dynamic_cast<TaskArticle*>(*it);
+      if (ta)
+      {
+        ta->set_start_paused(false);
+      }
     }
   }
 }
@@ -464,10 +591,17 @@ Queue :: add_task (Task * task, AddMode mode)
 void
 Queue :: add_tasks (const tasks_t& tasks, AddMode mode)
 {
+
   foreach_const (tasks_t, tasks, it) {
     TaskArticle * ta (dynamic_cast<TaskArticle*>(*it));
     if (ta)
+    {
       _mids.insert (ta->get_article().message_id);
+      if (ta->start_paused())
+      {
+        _stopped.insert(*it);
+      }
+    }
   }
 
   if (mode == TOP)
@@ -477,7 +611,7 @@ Queue :: add_tasks (const tasks_t& tasks, AddMode mode)
   else
     _tasks.add (tasks);
 
-  // asdf
+  // process all new tasks
   tasks_t tmp (tasks);
   foreach (tasks_t, tmp, it)
     process_task (*it);
@@ -505,6 +639,9 @@ Queue :: task_is_active (const Task * task) const
   if (task && task==_decoder_task)
     return true;
 
+  if (task && task==_encoder_task)
+    return true;
+
   bool task_has_nntp (false);
   foreach_const (nntp_to_task_t, _nntp_to_task, it)
     if ((task_has_nntp = task==it->second))
@@ -536,10 +673,27 @@ Queue :: remove_task (Task * task)
     TaskArticle * ta (dynamic_cast<TaskArticle*>(task));
     if (ta)
       _mids.erase (ta->get_article().message_id);
-
     _stopped.erase (task);
     _removing.erase (task);
     _tasks.remove (index);
+
+    // manually upkeep on ONE new taskupload to keep the queue going
+    TaskUpload * t  (dynamic_cast<TaskUpload*>(task));
+    if (t)
+    {
+      int max (_server_info.get_server_limits(t->_server));
+      _uploads.erase(t);
+      const tasks_t tmp (_tasks.begin(), _tasks.end());
+      foreach_const (tasks_t, tmp, it) {
+        Task * task (*it);
+        if (task->get_state()._work == Task::INITIAL)
+        {
+          give_task_an_upload_slot(dynamic_cast<TaskUpload*>(*it));
+          break;
+        }
+      }
+    }
+
     delete task;
   }
 
@@ -596,7 +750,8 @@ Queue :: check_in (NNTP * nntp, Health nntp_health)
 
   if ((nntp_health != ERR_NETWORK)
     && _is_online
-    && ((state._health != ERR_COMMAND) && (state._health != ERR_LOCAL))
+    && state._health != ERR_COMMAND && state._health != ERR_LOCAL
+    && state._health != ERR_NOSPACE
     && (state._work == Task::NEED_NNTP)
     && !_removing.count(task)
     && state._servers.count(nntp->_server)
@@ -618,6 +773,10 @@ Queue :: check_in (NNTP * nntp, Health nntp_health)
     if (state._health == ERR_LOCAL)
       fire_queue_error ("");
 
+    // tell if we reached the end of disk space
+    if (state._health == ERR_NOSPACE)
+      fire_queue_error (_("No space left on device."));
+
     // return the nntp to the pool
     const Quark& servername (nntp->_server);
     NNTP_Pool& pool (get_pool (servername));
@@ -632,7 +791,7 @@ void
 Queue :: check_in (Decoder* decoder UNUSED, Task* task)
 {
   // take care of our decoder counting...
-  _decoder_task = 0;
+  _decoder_task = nullptr;
 
   // notify the listeners if the task isn't active anymore...
   if (!task_is_active (task))
@@ -643,6 +802,9 @@ Queue :: check_in (Decoder* decoder UNUSED, Task* task)
   if (state._health == ERR_LOCAL)
     fire_queue_error ("");
 
+  if (state._health == ERR_NOSPACE)
+    fire_queue_error (_("No space left on device."));
+
   // pass our worker thread on to another task
   Task * next = find_first_task_needing_decoder ();
   if (next && (next!=task))
@@ -652,6 +814,33 @@ Queue :: check_in (Decoder* decoder UNUSED, Task* task)
   process_task (task);
 }
 
+void
+Queue :: check_in (Encoder* encoder UNUSED, Task* task)
+{
+  // take care of our decoder counting...
+  _encoder_task = nullptr;
+
+  // notify the listeners if the task isn't active anymore...
+  if (!task_is_active (task))
+    fire_task_active_changed (task, false);
+
+  // if the task hit an error, fire an error message
+  const Task::State state (task->get_state ());
+  if (state._health == ERR_LOCAL)
+    fire_queue_error ("");
+
+  if (state._health == ERR_NOSPACE)
+    fire_queue_error (_("No space left on device."));
+
+  // pass our worker thread on to another task
+  Task * next = find_first_task_needing_encoder ();
+  if (next && (next!=task))
+    process_task (next);
+
+  // what to do now with this task...
+  process_task (task);
+}
+
 void
 Queue :: move_up (const tasks_t& tasks)
 {
@@ -775,11 +964,11 @@ Queue :: get_stats (unsigned long   & queued_count,
     Task * task (*it);
 
     const Queue::TaskState state (tasks.get_state (task));
-    if (state == Queue::RUNNING || state == Queue::DECODING)
+    if (state == Queue::RUNNING || state == Queue::DECODING || state == Queue::ENCODING)
       ++running_count;
     else if (state == Queue::STOPPED)
       ++stopped_count;
-    else if (state == Queue::QUEUED || state == Queue::QUEUED_FOR_DECODE)
+    else if (state == Queue::QUEUED || state == Queue::QUEUED_FOR_DECODE || state == Queue::QUEUED_FOR_ENCODE)
       ++queued_count;
 
     if (state==Queue::RUNNING || state==Queue::QUEUED)
@@ -797,3 +986,15 @@ Queue :: get_stats (unsigned long   & queued_count,
   }
 }
 
+void
+Queue :: on_dl_limit_reached ()
+{
+  if (_prefs.get_flag("disconnect-on-dl-limit-reached", false))
+    set_online (false);
+}
+
+void
+Queue :: on_reset_xfer_bytes ()
+{
+  set_online (true);
+}
