@@ -13,17 +13,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <config.h>
 #include <cassert>
+#include <glib/gi18n.h>
 extern "C" {
-  #include <glib/gi18n.h>
+  #include <stdlib.h>
 }
 #include <pan/general/debug.h>
-#include <pan/general/foreach.h>
+#include <pan/general/macros.h>
 #include <pan/general/messages.h>
 #include <pan/general/utf8-utils.h>
 #include <pan/data/data.h>
@@ -53,8 +54,7 @@ TaskGroups :: TaskGroups (Data& data, const Quark& servername):
 }
 
 TaskGroups :: ~TaskGroups ()
-{
-}
+{}
 
 /***
 ****
@@ -78,6 +78,17 @@ TaskGroups :: use_nntp (NNTP * nntp)
 void
 TaskGroups :: on_nntp_line (NNTP               * nntp,
                             const StringView   & line)
+{
+  // gzip compression
+  if (nntp->_compression)
+  {
+    stream<<line;
+  }
+  else on_nntp_line_process (nntp, line);
+}
+void
+TaskGroups :: on_nntp_line_process (NNTP               * nntp UNUSED,
+                                    const StringView   & line)
 {
   char permission ('y');
   std::string name_str;
@@ -138,8 +149,38 @@ TaskGroups :: on_nntp_done (NNTP              * nntp,
   {
     _state.set_need_nntp (_servername);
   }
-  else // heath is OK or FAIL
+  else // health is OK or FAIL
   {
+
+    const Quark& server(nntp->_server);
+    CompressionType comp;
+    _data.get_server_compression_type(server, comp);
+    const bool is_gzipped (comp == HEADER_COMPRESS_XFEATURE);
+
+    if (is_gzipped)
+    {
+      std::ofstream of("tmp_out");
+      of << stream.str();
+      of.close();
+      std::stringstream out,out2;
+      bool fail = !compression::inflate_zlib(&stream, &out, comp);
+      if (!fail)
+      {
+        char buf[4096];
+        while (true)
+        {
+          std::istream& str = out.getline(buf, sizeof(buf));
+          if (str.fail() || str.bad() || str.eof()) break;
+          on_nntp_line_process(nntp, buf);
+        }
+      } else
+      {
+        _state.set_completed();
+        set_finished(ERR_LOCAL);
+      }
+
+    }
+
     if (_step == LIST_NEWSGROUPS)
     {
       int i (0);
